---
name: Release {{ namespace }}.{{ collection_name }}
{% raw %}
on: # yamllint disable-line rule:truthy
  release:
    types: [published]
jobs:
  release_automation_hub:
    uses: ansible/ansible-content-actions/.github/workflows/release_galaxy.yaml@main
    with:
      environment: release
    secrets:
      ansible_galaxy_api_key: ${{ secrets.ANSIBLE_GALAXY_API_KEY }}
{%- endraw %}
