{% raw %}---
ansible-navigator:
  logging:
    level: debug
    append: false
    file: $PWD/.logs/ansible-navigator.log

  playbook-artifact:
    enable: true
    save-as: "$PWD/.logs/{playbook_name}-artifact-{time_stamp}.json"
{%- endraw %}
