---
name: "CI"
{% raw %}
concurrency:
  group: ${{ github.head_ref || github.run_id }}
  cancel-in-progress: true

on: # yamllint disable-line rule:truthy
  pull_request:
    branches: [main]
  workflow_dispatch:
  # TO-DO: Below is an example cron scheduler. Uncomment and tweak it as per your requirement
  # schedule:
    # - cron: '0 0 * * *'

jobs:
  ansible-lint:
    uses: ansible/ansible-content-actions/.github/workflows/ansible_lint.yaml@main
{%- endraw %}
