---
# defaults file for {{ namespace }}.{{ collection_name }}.{{ role_name }}

# Variable that will be displayed in debug output
# This demonstrates proper role variable naming with the 'run_' prefix
{{ role_name }}_my_variable: "default_value"
