[defaults]
# Specify the inventory file
inventory = inventory/hosts.yml

# Define the directory for host and group variables
host_vars_inventory = inventory/host_vars
group_vars_inventory = inventory/group_vars

# Set the logging verbosity level
verbosity = 2

# Set the default user for SSH connections
remote_user = myuser

# Define the default become method
become_method = sudo

[persistent_connection]
# Controls how long the persistent connection will remain idle before it is destroyed
connect_timeout=30

# Controls the amount of time to wait for response from remote device before timing out persistent connection
command_timeout=30
