---
- name: Test the Hello World filter plugin
  ansible.builtin.set_fact:
    msg: {% raw %}"{{ 'ansible-creator' | {% endraw %}{{ namespace }}.{{ collection_name }}.{% raw %}sample_filter }}"{% endraw %}

- name: Assert that the filter worked
  ansible.builtin.assert:
    that:
      - msg == 'Hello, ansible-creator'
