# files we don't want prettier to ever to look into
.*/
coverage/

# Environments
.env
.venv
env/
venv/
ENV/
env.bak/
venv.bak/

# A linked collection directory created by pytest-ansible-units
collections/

tests/output/

README.md
