---
repos:
  - repo: https://github.com/ansible-network/collection_prep
    rev: 1.1.1
    hooks:
      - id: update-docs

  - repo: https://github.com/pre-commit/pre-commit-hooks
    rev: v4.4.0
    hooks:
      - id: check-merge-conflict
      - id: check-symlinks
      - id: debug-statements
      - id: end-of-file-fixer
      - id: no-commit-to-branch
        args: [--branch, main]
      - id: trailing-whitespace

  - repo: https://github.com/asottile/add-trailing-comma
    rev: v3.0.0
    hooks:
      - id: add-trailing-comma

  - repo: https://github.com/pre-commit/mirrors-prettier
    rev: "v3.0.0"
    hooks:
      - id: prettier
        entry: env CI=1 bash -c "prettier --list-different . || ec=$? && prettier --loglevel=error --write . && exit $ec"
        pass_filenames: false
        args: []
        additional_dependencies:
          - prettier
          - prettier-plugin-toml

  - repo: https://github.com/PyCQA/isort
    rev: 5.12.0
    hooks:
      - id: isort
        name: Sort import statements using isort
        args: ["--filter-files"]

  - repo: https://github.com/psf/black
    rev: 23.7.0
    hooks:
      - id: black

  - repo: https://github.com/pycqa/flake8
    rev: 7.0.0
    hooks:
      - id: flake8
